==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/sv/coptic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "detta kv.",
	"field-quarter-short-relative+1": "nästa kv.",
	"field-tue-relative+-1": "tisdag förra veckan",
	"field-year": "år",
	"field-wed-relative+0": "onsdag denna vecka",
	"field-wed-relative+1": "onsdag nästa vecka",
	"field-minute": "minut",
	"field-month-narrow-relative+-1": "förra mån.",
	"field-tue-narrow-relative+0": "denna tis.",
	"field-tue-narrow-relative+1": "nästa tis.",
	"field-thu-short-relative+0": "tors. denna vecka",
	"field-day-short-relative+-1": "i går",
	"field-thu-short-relative+1": "tors. nästa vecka",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i förrgår",
	"field-day-relative+1": "i morgon",
	"field-week-narrow-relative+0": "denna v.",
	"field-day-relative+2": "i övermorgon",
	"field-week-narrow-relative+1": "nästa v.",
	"field-wed-narrow-relative+-1": "förra ons.",
	"field-year-narrow": "år",
	"field-year-narrow-relative+0": "i år",
	"field-tue-relative+0": "tisdag denna vecka",
	"field-year-narrow-relative+1": "nästa år",
	"field-tue-relative+1": "tisdag nästa vecka",
	"field-second-short": "sek",
	"field-week-relative+0": "denna vecka",
	"field-month-relative+0": "denna månad",
	"field-week-relative+1": "nästa vecka",
	"field-month-relative+1": "nästa månad",
	"field-sun-narrow-relative+0": "denna sön.",
	"field-mon-short-relative+0": "mån. denna vecka",
	"field-sun-narrow-relative+1": "nästa sön.",
	"field-mon-short-relative+1": "mån. nästa vecka",
	"field-second-relative+0": "nu",
	"field-month-short": "m",
	"field-day": "dag",
	"field-year-relative+-1": "i fjol",
	"field-sat-short-relative+-1": "lör. förra veckan",
	"field-hour-relative+0": "denna timme",
	"field-second-short-relative+0": "nu",
	"field-wed-relative+-1": "onsdag förra veckan",
	"field-sat-narrow-relative+-1": "förra lör.",
	"field-second": "sekund",
	"field-hour-short-relative+0": "denna timme",
	"field-quarter": "kvartal",
	"field-week-short": "v",
	"field-day-narrow-relative+0": "i dag",
	"field-day-narrow-relative+1": "i morgon",
	"field-day-narrow-relative+2": "i övermorgon",
	"field-tue-short-relative+0": "tis. denna vecka",
	"field-tue-short-relative+1": "tis. nästa vecka",
	"field-month-short-relative+-1": "förra mån.",
	"field-mon-relative+-1": "måndag förra veckan",
	"field-month": "månad",
	"field-day-narrow": "dag",
	"field-minute-short": "min",
	"field-dayperiod": "fm/em",
	"field-sat-short-relative+0": "lör. denna vecka",
	"field-sat-short-relative+1": "lör. nästa vecka",
	"field-second-narrow": "s",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"field-day-narrow-relative+-1": "i går",
	"field-year-short": "år",
	"field-day-narrow-relative+-2": "i förrgår",
	"field-quarter-relative+-1": "förra kvartalet",
	"field-week-narrow-relative+-1": "förra v.",
	"field-sat-relative+-1": "lördag förra veckan",
	"field-hour": "timme",
	"field-minute-narrow-relative+0": "denna minut",
	"months-format-wide": [
		"tout",
		"bâbâ",
		"hâtour",
		"kiahk",
		"toubah",
		"amshîr",
		"barmahât",
		"barmoudah",
		"bashans",
		"ba’ounah",
		"abîb",
		"misra",
		"al-nasi"
	],
	"field-month-relative+-1": "förra månaden",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "denna lör.",
	"field-fri-relative+0": "fredag denna vecka",
	"field-sat-narrow-relative+1": "nästa lör.",
	"field-fri-relative+1": "fredag nästa vecka",
	"field-month-narrow-relative+0": "denna mån.",
	"field-month-narrow-relative+1": "nästa mån.",
	"field-sun-short-relative+0": "sön. denna vecka",
	"field-sun-short-relative+1": "sön. nästa vecka",
	"field-week-relative+-1": "förra veckan",
	"field-quarter-short-relative+-1": "förra kv.",
	"field-minute-short-relative+0": "denna minut",
	"months-format-abbr": [
		"tout",
		"bâbâ",
		"hâtour",
		"kiahk",
		"toubah",
		"amshîr",
		"barmahât",
		"barmoudah",
		"bashans",
		"ba’ounah",
		"abîb",
		"misra",
		"al-nasi"
	],
	"field-quarter-relative+0": "detta kvartal",
	"field-minute-relative+0": "denna minut",
	"field-quarter-relative+1": "nästa kvartal",
	"field-wed-short-relative+-1": "ons. förra veckan",
	"field-thu-short-relative+-1": "tors. förra veckan",
	"field-year-narrow-relative+-1": "i fjol",
	"field-mon-narrow-relative+-1": "förra mån.",
	"field-thu-narrow-relative+-1": "förra tors.",
	"field-tue-narrow-relative+-1": "förra tis.",
	"field-wed-short-relative+0": "ons. denna vecka",
	"months-standAlone-wide": [
		"Tout",
		"Bâbâ",
		"Hâtour",
		"Kiahk",
		"Toubah",
		"Amshîr",
		"Barmahât",
		"Barmoudah",
		"Bashans",
		"Ba’ounah",
		"Abîb",
		"Misra",
		"Al-nasi"
	],
	"field-wed-short-relative+1": "ons. nästa vecka",
	"field-sun-relative+-1": "söndag förra veckan",
	"field-second-narrow-relative+0": "nu",
	"field-weekday": "veckodag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "detta kv.",
	"field-sat-relative+0": "lördag denna vecka",
	"field-day-short-relative+1": "i morgon",
	"field-quarter-narrow-relative+1": "nästa kv.",
	"field-sat-relative+1": "lördag nästa vecka",
	"field-day-short-relative+2": "i övermorgon",
	"field-week-short-relative+0": "denna v.",
	"field-week-short-relative+1": "nästa v.",
	"months-standAlone-abbr": [
		"Tout",
		"Bâbâ",
		"Hâtour",
		"Kiahk",
		"Toubah",
		"Amshîr",
		"Barmahât",
		"Barmoudah",
		"Bashans",
		"Ba’ounah",
		"Abîb",
		"Misra",
		"Al-nasi"
	],
	"field-month-short-relative+0": "denna mån.",
	"field-month-short-relative+1": "nästa mån.",
	"field-thu-narrow-relative+0": "denna tors.",
	"field-thu-narrow-relative+1": "nästa tors.",
	"field-sun-narrow-relative+-1": "förra sön.",
	"field-mon-short-relative+-1": "mån. förra veckan",
	"field-thu-relative+0": "torsdag denna vecka",
	"field-thu-relative+1": "torsdag nästa vecka",
	"field-fri-short-relative+-1": "fre. förra veckan",
	"field-thu-relative+-1": "torsdag förra veckan",
	"field-week": "vecka",
	"field-wed-narrow-relative+0": "denna ons.",
	"field-wed-narrow-relative+1": "nästa ons.",
	"field-quarter-narrow-relative+-1": "förra kv.",
	"field-year-short-relative+0": "i år",
	"field-year-short-relative+1": "nästa år",
	"field-fri-short-relative+0": "fre. denna vecka",
	"field-fri-short-relative+1": "fre. nästa vecka",
	"field-week-short-relative+-1": "förra v.",
	"field-hour-narrow-relative+0": "denna timme",
	"field-hour-short": "tim",
	"field-month-narrow": "mån",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "förra fre.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "nästa år",
	"field-fri-relative+-1": "fredag förra veckan",
	"field-tue-short-relative+-1": "tis. förra veckan",
	"field-minute-narrow": "m",
	"field-mon-narrow-relative+0": "denna mån.",
	"field-mon-narrow-relative+1": "nästa mån.",
	"field-year-short-relative+-1": "i fjol",
	"field-zone": "tidszon",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "sön. förra veckan",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i förrgår",
	"field-sun-relative+0": "söndag denna vecka",
	"field-sun-relative+1": "söndag nästa vecka",
	"field-day-short": "dag",
	"field-week-narrow": "v",
	"field-era": "era",
	"field-fri-narrow-relative+0": "denna fre.",
	"field-fri-narrow-relative+1": "nästa fre."
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/sv/coptic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "detta kv.",
	"field-quarter-short-relative+1": "nästa kv.",
	"field-tue-relative+-1": "tisdag förra veckan",
	"field-year": "år",
	"field-wed-relative+0": "onsdag denna vecka",
	"field-wed-relative+1": "onsdag nästa vecka",
	"field-minute": "minut",
	"field-month-narrow-relative+-1": "förra mån.",
	"field-tue-narrow-relative+0": "denna tis.",
	"field-tue-narrow-relative+1": "nästa tis.",
	"field-thu-short-relative+0": "tors. denna vecka",
	"field-day-short-relative+-1": "i går",
	"field-thu-short-relative+1": "tors. nästa vecka",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i förrgår",
	"field-day-relative+1": "i morgon",
	"field-week-narrow-relative+0": "denna v.",
	"field-day-relative+2": "i övermorgon",
	"field-week-narrow-relative+1": "nästa v.",
	"field-wed-narrow-relative+-1": "förra ons.",
	"field-year-narrow": "år",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "i år",
	"field-tue-relative+0": "tisdag denna vecka",
	"field-year-narrow-relative+1": "nästa år",
	"field-tue-relative+1": "tisdag nästa vecka",
	"field-weekdayOfMonth": "veckodag i månad",
	"field-second-short": "sek",
	"field-weekdayOfMonth-narrow": "veckodag i mån.",
	"field-week-relative+0": "denna vecka",
	"field-month-relative+0": "denna månad",
	"field-week-relative+1": "nästa vecka",
	"field-month-relative+1": "nästa månad",
	"field-sun-narrow-relative+0": "denna sön.",
	"field-mon-short-relative+0": "mån. denna vecka",
	"field-sun-narrow-relative+1": "nästa sön.",
	"field-mon-short-relative+1": "mån. nästa vecka",
	"field-second-relative+0": "nu",
	"field-weekOfMonth": "vecka i månaden",
	"field-month-short": "m",
	"field-day": "dag",
	"field-dayOfYear-short": "dag under året",
	"field-year-relative+-1": "i fjol",
	"field-sat-short-relative+-1": "lör. förra veckan",
	"field-hour-relative+0": "denna timme",
	"field-second-short-relative+0": "nu",
	"field-wed-relative+-1": "onsdag förra veckan",
	"field-sat-narrow-relative+-1": "förra lör.",
	"field-second": "sekund",
	"field-hour-short-relative+0": "denna timme",
	"field-quarter": "kvartal",
	"field-week-short": "v",
	"field-day-narrow-relative+0": "idag",
	"field-day-narrow-relative+1": "imorgon",
	"field-day-narrow-relative+2": "i övermorgon",
	"field-tue-short-relative+0": "tis. denna vecka",
	"field-tue-short-relative+1": "tis. nästa vecka",
	"field-month-short-relative+-1": "förra mån.",
	"field-mon-relative+-1": "måndag förra veckan",
	"field-month": "månad",
	"field-day-narrow": "dag",
	"field-minute-short": "min",
	"field-dayperiod": "fm/em",
	"field-sat-short-relative+0": "lör. denna vecka",
	"field-sat-short-relative+1": "lör. nästa vecka",
	"field-second-narrow": "s",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"field-day-narrow-relative+-1": "igår",
	"field-year-short": "år",
	"field-day-narrow-relative+-2": "i förrgår",
	"field-quarter-relative+-1": "förra kvartalet",
	"field-dayperiod-narrow": "fm/em",
	"field-week-narrow-relative+-1": "förra v.",
	"field-dayOfYear": "dag under året",
	"field-sat-relative+-1": "lördag förra veckan",
	"field-hour": "timme",
	"field-minute-narrow-relative+0": "denna minut",
	"months-format-wide": [
		"tout",
		"bâbâ",
		"hâtour",
		"kiahk",
		"toubah",
		"amshîr",
		"barmahât",
		"barmoudah",
		"bashans",
		"ba’ounah",
		"abîb",
		"misra",
		"al-nasi"
	],
	"field-month-relative+-1": "förra månaden",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "denna lör.",
	"field-fri-relative+0": "fredag denna vecka",
	"field-sat-narrow-relative+1": "nästa lör.",
	"field-fri-relative+1": "fredag nästa vecka",
	"field-month-narrow-relative+0": "denna mån.",
	"field-month-narrow-relative+1": "nästa mån.",
	"field-sun-short-relative+0": "sön. denna vecka",
	"field-sun-short-relative+1": "sön. nästa vecka",
	"field-week-relative+-1": "förra veckan",
	"field-quarter-short-relative+-1": "förra kv.",
	"field-minute-short-relative+0": "denna minut",
	"months-format-abbr": [
		"tout",
		"bâbâ",
		"hâtour",
		"kiahk",
		"toubah",
		"amshîr",
		"barmahât",
		"barmoudah",
		"bashans",
		"ba’ounah",
		"abîb",
		"misra",
		"al-nasi"
	],
	"field-quarter-relative+0": "detta kvartal",
	"field-minute-relative+0": "denna minut",
	"field-quarter-relative+1": "nästa kvartal",
	"field-wed-short-relative+-1": "ons. förra veckan",
	"field-thu-short-relative+-1": "tors. förra veckan",
	"field-year-narrow-relative+-1": "i fjol",
	"field-thu-narrow-relative+-1": "förra tors.",
	"field-tue-narrow-relative+-1": "förra tis.",
	"field-weekOfMonth-short": "vk. i mån.",
	"field-wed-short-relative+0": "ons. denna vecka",
	"months-standAlone-wide": [
		"Tout",
		"Bâbâ",
		"Hâtour",
		"Kiahk",
		"Toubah",
		"Amshîr",
		"Barmahât",
		"Barmoudah",
		"Bashans",
		"Ba’ounah",
		"Abîb",
		"Misra",
		"Al-nasi"
	],
	"field-wed-short-relative+1": "ons. nästa vecka",
	"field-sun-relative+-1": "söndag förra veckan",
	"field-second-narrow-relative+0": "nu",
	"field-weekday": "veckodag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "detta kv.",
	"field-sat-relative+0": "lördag denna vecka",
	"field-day-short-relative+1": "i morgon",
	"field-quarter-narrow-relative+1": "nästa kv.",
	"field-sat-relative+1": "lördag nästa vecka",
	"field-day-short-relative+2": "i övermorgon",
	"field-week-short-relative+0": "denna v.",
	"field-week-short-relative+1": "nästa v.",
	"months-standAlone-abbr": [
		"Tout",
		"Bâbâ",
		"Hâtour",
		"Kiahk",
		"Toubah",
		"Amshîr",
		"Barmahât",
		"Barmoudah",
		"Bashans",
		"Ba’ounah",
		"Abîb",
		"Misra",
		"Al-nasi"
	],
	"field-dayOfYear-narrow": "dag under året",
	"field-month-short-relative+0": "denna mån.",
	"field-month-short-relative+1": "nästa mån.",
	"field-weekdayOfMonth-short": "veckodag i mån.",
	"field-zone-narrow": "tidszon",
	"field-thu-narrow-relative+0": "denna tors.",
	"field-thu-narrow-relative+1": "nästa tors.",
	"field-sun-narrow-relative+-1": "förra sön.",
	"field-mon-short-relative+-1": "mån. förra veckan",
	"field-thu-relative+0": "torsdag denna vecka",
	"field-thu-relative+1": "torsdag nästa vecka",
	"field-fri-short-relative+-1": "fre. förra veckan",
	"field-thu-relative+-1": "torsdag förra veckan",
	"field-week": "vecka",
	"field-wed-narrow-relative+0": "denna ons.",
	"field-wed-narrow-relative+1": "nästa ons.",
	"field-quarter-narrow-relative+-1": "förra kv.",
	"field-year-short-relative+0": "i år",
	"field-dayperiod-short": "fm/em",
	"field-year-short-relative+1": "nästa år",
	"field-fri-short-relative+0": "fre. denna vecka",
	"field-fri-short-relative+1": "fre. nästa vecka",
	"field-week-short-relative+-1": "förra v.",
	"field-hour-narrow-relative+0": "denna timme",
	"field-hour-short": "tim",
	"field-zone-short": "tidszon",
	"field-month-narrow": "mån",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "förra fre.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "nästa år",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "fredag förra veckan",
	"field-tue-short-relative+-1": "tis. förra veckan",
	"field-minute-narrow": "m",
	"field-year-short-relative+-1": "i fjol",
	"field-zone": "tidszon",
	"field-weekOfMonth-narrow": "vk.i mån.",
	"field-weekday-narrow": "veckodag",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "sön. förra veckan",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i förrgår",
	"field-weekday-short": "veckodag",
	"field-sun-relative+0": "söndag denna vecka",
	"field-sun-relative+1": "söndag nästa vecka",
	"field-day-short": "dag",
	"field-week-narrow": "v",
	"field-era": "era",
	"field-fri-narrow-relative+0": "denna fre.",
	"field-fri-narrow-relative+1": "nästa fre."
}
//end v1.x content
);
